@@ -1,10 +1,10 @@
 ﻿__author__ = "The ProSuite Authors"
 __copyright__ = "Copyright 2021-2023, The ProSuite Authors"
 __license__ = "MIT"
-__version__ = "1.0.1.0"
+__version__ = "1.0.2.6"
 __maintainer__ = "Dira GeoSystems"
 __email__ = "programmers@dirageosystems.ch"
-__date__  = "16.01.2023"
+__date__  = "21/02/2023"
 __status__ = "Production"
 
 
